jacinle.concurrency.zmq\_utils
==============================

.. automodule:: jacinle.concurrency.zmq_utils

   
   
   

   
   
   

   
   
   .. rubric:: Functions

   .. autosummary::
   
      bind_to_random_ipc
      graceful_close
      iter_recv
      json_dumpb
      json_loadb
      pull_pyobj
      push_pyobj
      req_recv_json
      req_send_and_recv
      req_send_json
      router_recv_json
      router_send_json
      uid
   
   

   
   
   











.. rubric:: Functions

.. autofunction:: bind_to_random_ipc

.. autofunction:: graceful_close

.. autofunction:: iter_recv

.. autofunction:: json_dumpb

.. autofunction:: json_loadb

.. autofunction:: pull_pyobj

.. autofunction:: push_pyobj

.. autofunction:: req_recv_json

.. autofunction:: req_send_and_recv

.. autofunction:: req_send_json

.. autofunction:: router_recv_json

.. autofunction:: router_send_json

.. autofunction:: uid


